B2CAccessToken constructor
Creates an access token.
The subject express the owner of the access token, the token argument
is the string representation of the token itself, and expireOn indicates
the date-time when the token will expire.
Implementation
B2CAccessToken(this.subject, this.token, this.expireOn);