B2CUserInfo class

Utility class to manage and store users informations.

Constructors

B2CUserInfo(String subject, String username, Map<String, dynamic> claims)
Default construtor. Use only in plugin extension.
B2CUserInfo.fromJson(String subject, Map<String, dynamic> data)
Creates a B2CUserInfo from a JSON map.

Properties

claims ↔ Map<String, dynamic>
Map of user claims.
latefinal
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject ↔ String
Unique id string for each user. Dependant from the B2C configuration it uses the
latefinal
username ↔ String
Email, username, or phone-number (depending on B2C configuration)
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
Returns a JSON representation.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited